@@ -72,7 +72,7 @@ impl MappedAddress {
 
         let family = u16::from_be_bytes([v[0], v[1]]);
         if family != FAMILY_IPV6 && family != FAMILY_IPV4 {
-            return Err(Error::ErrOthers(format!("bad value {}", family)).into());
+            return Err(Error::new(format!("bad value {}", family)).into());
         }
         self.port = u16::from_be_bytes([v[2], v[3]]);
 
