@@ -9,8 +9,8 @@ pub mod agent;
 pub mod attributes;
 pub mod checks;
 pub mod client;
+pub mod error;
 pub mod error_code;
-pub mod errors;
 pub mod fingerprint;
 pub mod integrity;
 pub mod message;
